#!/usr/bin/env python3
#! -*- Encoding: utf-8 -*-

import os

class function(object):

    @staticmethod
    def get_dict_code_name():
        '''
        Check if the code file exists and return the file name
        '''
        
        try:
            dict_code = "phone_email_verifier/code.txt"

            with open(dict_code): pass

            return dict_code

        except IOError:
            return os.getenv('DICT_CODE')
        else:
            return None


#!/usr/bin/env python3
#! -*- Encoding: utf-8 -*-

import re
import csv

try:
    from .function import function as func
    from .ProcessException import ProcessException
    from .treatment_email import Treatment_email as Email
    from .treatment_phone import Treatement_phone as Phone
except ImportError as IE:
    print(f"ERROR: {IE}")


class phone_email_verifier(object):
    '''
    Object phone_email_verifier 
    '''

    def __init__(self):
        '''
        Constructor 
        '''
        self.email = None
        self.phone = None
        self.country = None
        self.indicative_code = None
        self.specificity = None
        
    def contact_is_list(self, contact):
        '''
        Methode 
        Qui permet de faire la verification sur une list de contact
        is contact n'est pas une list 
        Une exception est enclancher
        '''
        try:
            if type(contact) is not list:
                raise ProcessException('the contact list is not formatted to the program requirement')
        except ProcessException as e:
            raise ProcessException(f"ERROR : {e}")

    def set_phone_list(self, phone, country=None, indicative_code=None, specificity=None):
        '''
        Methode
        Qui permet de recupérer les information pour la 
        verification des contacts de la list
        '''

        try:
            success = 0

            if country is not None and indicative_code is not None:
                with open(func.get_dict_code_name(), encoding='utf-8') as country_info:
                    for ligne in country_info:
                        info = ligne.split(',')
                        if country == info[1] and re.match(r'^[\\' + info[2] + ']{2,4}', indicative_code) is not None:
                            success = 0
                            break
                        success +=1
                    
            
            if success > 0:
                raise Exception('The country does not match this code')
                        
            self.contact_is_list(phone)#appel de la method contact_is_list

            self.phone = phone

            self.country = country

            self.indicative_code = self.get_code(country) if country is not None and indicative_code is None else indicative_code
            
            self.specificity = specificity

        except Exception as e:
            print(f'ERROR in program: \n {e}')
        
    
    def get_code(self, country):
        '''
        Method get_code
        Charger de donner le code indicatif d'un pays
        selectionner 
        '''
        with open(func.get_dict_code_name(), encoding='utf-8') as country_info:
            for ligne in country_info:
                info = ligne.split(',')
                if country == info[1]:
                    return info[2]

        raise Exception('the country to select does not have its code identify in our data')

    def set_email_list(self, email, country=None):
        '''
        Methode
        Qui permet de recupérer les informations pour la 
        verification des contacts de la list
        '''
        try:
            self.contact_is_list(email)#appel de la method contact_is_list
            self.email = email
            self.country = country if country is not None else None 
        except Exception as e:
            print(f'ERROR in program: \n {e}')

    
    def set_phone_in_file(self, file, country=None, indicative_code=None, colum=None):
        '''
        Method set_phone_in_file
        Permet de rechercher des numéro dans un fichier "TXT" ou "CSV"
        Pour la vérification
        :country, permet de selectionner le pays Ex: CI, FR, ...
        :indicative_code, code indicatif du pays pas obligatoire
        :colum, permet de dire dans quel colonne se situe le numéro si le fichier est un CSV
        '''
        try:
            ext = file.split('.')
            ext = ext[len(ext) - 1:]

            if colum is not None and type(colum) is not int:
                raise Exception('The type is not (int)')

            if ext[0].upper() == 'TXT':
                with open(file, encoding='utf-8') as contact_of_file:
                    self.phone = [phone.split(',')[0] for phone in contact_of_file]
                
                self.country = country
                self.indicative_code = self.get_code(country) if country is not None and indicative_code is None else indicative_code
                
            elif ext[0].upper() == 'CSV':
                self.phone = self.get_contact_of_file(file, colum)
                self.country = country
                self.indicative_code = self.get_code(country) if country is not None and indicative_code is None else indicative_code

        except Exception as e:
            print(f'ERROR: {e}')

    def set_email_in_file(self, file, country=None, colum=None):
        '''
        Method set_email_in_file
        Permet de rechercher des numéro dans un fichier "TXT" ou "CSV"
        Pour la vérification
        :country, vous permet de selectionner le pays Ex: .ci, .fr ...
        :colum, permet de dire dans quel colonne se situe le email si le fichier est un CSV
        '''
        try:
            ext = file.split('.')
            ext = ext[len(ext) - 1:]

            if colum is not None and type(colum) is not int:
                raise Exception('The type is not (int)')

            if ext[0].upper() == 'TXT':
                with open(file, encoding='utf-8') as contact_of_file:
                    self.email = [email.split(',')[0] for email in contact_of_file]
                
                self.country = country
                
            elif ext[0].upper() == 'CSV':
                self.email = self.get_contact_of_file(file, colum)
                self.country = country

        except Exception as e:
            print(f'ERROR: {e}')

    def get_contact_of_file(self, file, colum):
        with open(file, newline='') as contact_of_file:
            contact_list = csv.reader(contact_of_file)
            if colum is not None:
                contacts = [cnt[0] for cnt in contact_list]
            else:
                contacts = [cnt[colum] for cnt in contact_list]

        return contacts

    def treatment_selected(self):
        '''
        Methode
        Qui permet de faire une selection de traitement
        '''
        return True if self.email is not None else False

    def exec(self):
        if self.email is not None or self.phone is not None:
            if self.treatment_selected():
                treatment_email = Email(self.email, self.country)
                treatment_email.generate_email_list()
                return dict(
                    OK=treatment_email.get_contact_success_list(),
                    ERROR=treatment_email.get_contact_error_list()
                )
            else:
                treatment_phone = Phone(self.phone, dict(country=self.country, indicative_code=self.indicative_code, specificity=self.specificity))
                treatment_phone.generate_phone_list()
                return dict(
                    OK=treatment_phone.get_contact_success_list(),
                    ERROR=treatment_phone.get_contact_error_list()
                )
        else:
            return 0


#!/usr/bin/env python3
#! -*- Encoding: utf-8 -*-

import re

try:
    from .treatment import Treatment
except ImportError as IE:
    print(f"ERROR: {IE}")


class Treatment_email(Treatment):
    '''
    Object Treatment_email
    Qui faire le filtre sur les E-mail
    '''

    def __init__(self, contacts, other=None):
        '''
        Constructor
        '''
        Treatment.__init__(self, contacts)
        
        if type(other) is str :
            country = "[" + other.lower() + "]"
        else:
            country = "[a-zA-z]{2,3}\Z"

        self.regex = re.compile(r"^[a-z0-9._-]+@[a-z0-9._-]+\." + country)
    
    def generate_email_list(self):
        '''
        Method generate_email_list
        '''

        old_contacts = self.contacts[:]

        for contact in old_contacts:
            if self.filter_email(contact):
                self.new_contacts.append(contact)
            else:
                self.error_contacts.append(contact)


    def filter_email(self, contact):
        '''
        Method filter_email
        Verifie si le mail est bien formaté
        '''
        return True if self.regex.match(contact) is not None else False


#!/usr/bin/env python3
#! -*- Encoding: utf-8 -*-

import re

class Treatment(object):
    '''
    Object Treatment
    Object of general treatment on contact (e-mail, phone)
    '''
    def __init__(self, contacts, other=None):
        '''
        Constructor
        '''
        self.error_contacts = list()
        self.new_contacts = list()
        self.contacts = contacts

    def get_contact_success_list(self):
        return self.new_contacts

    def get_contact_error_list(self):
        return self.error_contacts

    def get_contact_old_list(self):
        return self.contacts

    def number_contact_ok(self):
        return len(self.new_contacts)

    def number_contact_no_ok(self):
        return len(self.error_contacts)
        


from distutils.core import setup
import setuptools

with open('README.md', 'r', encoding='utf-8') as readme:
    long_description = readme.read()

setup(
    name='phone_email_verifier',
    version='0.0.3',
    description='Validation of the email or international or local telephone number',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Christian BOGRO',
    author_email='bogrolcr@gmail.com',
    license='MIT',
    url='https://github.com/Bogro/phone_email_verifier',
    packages=setuptools.find_packages(),
    download_url='https://github.com/Bogro/phone_email_verifier/tarball/master',
    keywords = ['email', 'phone number', 'filter', 'blocking', 'text', 'phone local', 'phone international'],
)


#!/usr/bin/env python3
#! -*- Encoding: utf-8 -*-

import re

try:
    from .function import function as func
    from .treatment import Treatment
    from .ProcessException import ProcessException
except ImportError as IE:
    print(f"ERROR: {IE}")


class Treatement_phone(Treatment):
    '''
    Object Treatement_phone
    Qui faire le filtre sur les numéro de téléphone
    '''

    def __init__(self, contacts, other=None):
        '''
        Constructor
        '''
        Treatment.__init__(self, contacts)
        self.other = other
        self.regex = re.compile(r'[\+\d]{6,15}\Z')
    
    def generate_phone_list(self):
        old_contacts = [re.sub(r"[/ _-]", "", phone) for phone in self.contacts[:]]
        for contact in old_contacts:
            if self.filter_phone(contact):
                self.new_contacts.append(contact)
            else:
                self.error_contacts.append(contact)

    def filter_by_all_country(self, contact):
        with open(func.get_dict_code_name(), encoding='utf-8') as country_info:
            for ligne in country_info:
                regex = f"(^\\{ligne.split(',')[2]})"
                reg = re.compile(regex)
                if reg.match(contact) is not None:
                    return True
            return False

    def filter_by_code(self, contact, country, code=None):

        if code is not None:
            regex = f'^(\\{code})'
            if re.match(regex, contact) is not None:
                return True
        else:
            with open(func.get_dict_code_name(), encoding='utf-8') as country_info:
                for ligne in country_info:
                    if country.upper() in ligne:
                        if re.match(r'^(\\' + ligne.split(',')[2] + ')', contact) is not None:
                            return True
                return False

    def filter_phone(self, contact):

        try:
            if self.regex.match(contact) is not None:
                if self.other['country'] is None:
                    return self.filter_by_all_country(contact)
                else:
                    return self.filter_by_code(contact, self.other['country'], self.other['indicative_code'])
            else:
                return False
                
        except ProcessException as e:
            print(f'ERROR: {e}')
            return False
            

        